==> phpnuke-5.5.tgz: www/phpnuke/html/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","ISO-8859-2");
define("_SEARCH","Keress");
define("_LOGIN","Belps");
define("_WRITES","Szerz:");
define("_POSTEDON","Ideje:");
define("_NICKNAME","Felhasznlnv");
define("_PASSWORD","Jelsz");
define("_WELCOMETO","dvzl a");
define("_EDIT","Szerkeszts");
define("_DELETE","Trls");
define("_POSTEDBY","rta:");
define("_READS","olvass");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Vissza</a> ]");
define("_COMMENTS","hozzszls");
define("_PASTARTICLES","Elz cikkek");
define("_OLDERARTICLES","Rgebbi cikkek");
define("_BY","Szerz:");
define("_ON","Ideje:");
define("_LOGOUT","Kilps");
define("_WAITINGCONT","Jvhagysra vr tartalom");
define("_SUBMISSIONS","Jvhagysra vr tartalom");
define("_WREVIEWS","Jvhagysra vr ismertetk");
define("_WLINKS","Jvhagysra vr linkek");
define("_EPHEMERIDS","vfordulk");
define("_ONEDAY","vfordulk");
define("_ASREGISTERED","Mg nem regisztrltad magad? <a href=\"modules.php?name=Your_Account\">Itt megteheted</a>. A regisztrlt felhasznlk szmos elnnyel rendelkeznek: dizjnvlts, hozzszlsok belltsa, s hozzszlsok sajt nv alatt.");
define("_MENUFOR","Szemlyes men:");
define("_NOBIGSTORY","A mai napnak mg nincs \"nagy sztorija\".");
define("_BIGSTORY","A legolvasottabb cikk ma:");
define("_SURVEY","Szavazgp");
define("_POLLS","Szavazsok");
define("_PCOMMENTS","Hozzszlsok:");
define("_RESULTS","Eredmnyek");
define("_HREADMORE","tovbb...");
define("_CURRENTLY","Jelenleg,");
define("_GUESTS","vendg s");
define("_MEMBERS","regisztrlt felhasznl olvas bennnket.");
define("_YOUARELOGGED","Szia,");
define("_YOUHAVE","");
define("_PRIVATEMSG","szemlyes zeneted van.");
define("_YOUAREANON","Jelenleg nvtelen ltogat vagy. Ingyenesen regisztrlhatod magad, <a href=\"modules.php?name=Your_Account\">ide</a> kattintva");
define("_NOTE","Megjegyzs:");
define("_ADMIN","Adminisztrci:");
define("_WERECEIVED","sszesen");
define("_PAGESVIEWS","tallatot kaptunk az oldal indtsa ta:");
define("_TOPIC","Tma");
define("_UDOWNLOADS","Szmll");
define("_VOTE","szavazat");
define("_VOTES","szavazat");
define("_MVIEWADMIN","Csak adminisztrtoroknak");
define("_MVIEWUSERS","Csak regisztrlt tagoknak");
define("_MVIEWANON","Csak nvtelen ltogatknak");
define("_MVIEWALL","Minden ltogatnak");
define("_EXPIRELESSHOUR","Lejrat: kevesebb, mint egy ra");
define("_EXPIREIN","Lejrat ideje:");
define("_HTTPREFERERS","HTTP utalsok");
define("_UNLIMITED","Korltlan");
define("_HOURS","ra");
define("_RSSPROBLEM","Jelenleg nem mkdik a site tartalomszolgltatsa");
define("_SELECTLANGUAGE","Vlassz nyelvet");
define("_SELECTGUILANG","Vlassz nyelvet:");
define("_NONE","Semmi");
define("_BLOCKPROBLEM","<center>There is a problem right now with this block.</center>");
define("_BLOCKPROBLEM2","<center>There isn't content right now for this block.</center>");
define("_MODULENOTACTIVE","Sorry, this Module isn't active!");
define("_NOACTIVEMODULES","Inactive Modules");
define("_FORADMINTESTS","(for Admin tests)");
define("_BBFORUMS","Forums");
define("_ACCESSDENIED", "Access Denied");
define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
define("_DATESTRING","%B %d, %A, %T");
define("_DATESTRING2","%B %d, %A");
define("_DATE","Date");
define("_HOUR","Hour");
define("_UMONTH","Month");
define("_YEAR","Year");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","ISO-8859-2");
define("_SEARCH","Keress");
define("_LOGIN","Belps");
define("_WRITES","Szerz:");
define("_POSTEDON","Ideje:");
define("_NICKNAME","Felhasznlnv");
define("_PASSWORD","Jelsz");
define("_WELCOMETO","dvzl a");
define("_EDIT","Szerkeszts");
define("_DELETE","Trls");
define("_POSTEDBY","rta:");
define("_READS","olvass");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Vissza</a> ]");
define("_COMMENTS","hozzszls");
define("_PASTARTICLES","Elz cikkek");
define("_OLDERARTICLES","Rgebbi cikkek");
define("_BY","Szerz:");
define("_ON","Ideje:");
define("_LOGOUT","Kilps");
define("_WAITINGCONT","Jvhagysra vr tartalom");
define("_SUBMISSIONS","Jvhagysra vr tartalom");
define("_WREVIEWS","Jvhagysra vr ismertetk");
define("_WLINKS","Jvhagysra vr linkek");
define("_EPHEMERIDS","vfordulk");
define("_ONEDAY","vfordulk");
define("_ASREGISTERED","Mg nem regisztrltad magad? <a href=\"modules.php?name=Your_Account\">Itt megteheted</a>. A regisztrlt felhasznlk szmos elnnyel rendelkeznek: dizjnvlts, hozzszlsok belltsa, s hozzszlsok sajt nv alatt.");
define("_MENUFOR","Szemlyes men:");
define("_NOBIGSTORY","A mai napnak mg nincs \"nagy sztorija\".");
define("_BIGSTORY","A legolvasottabb cikk ma:");
define("_SURVEY","Szavazgp");
define("_POLLS","Szavazsok");
define("_PCOMMENTS","Hozzszlsok:");
define("_RESULTS","Eredmnyek");
define("_HREADMORE","tovbb...");
define("_CURRENTLY","Jelenleg,");
define("_GUESTS","vendg s");
define("_MEMBERS","regisztrlt felhasznl olvas bennnket.");
define("_YOUARELOGGED","Szia,");
define("_YOUHAVE","");
define("_PRIVATEMSG","szemlyes zeneted van.");
define("_YOUAREANON","Jelenleg nvtelen ltogat vagy. Ingyenesen regisztrlhatod magad, <a href=\"modules.php?name=Your_Account\">ide</a> kattintva");
define("_NOTE","Megjegyzs:");
define("_ADMIN","Adminisztrci:");
define("_WERECEIVED","sszesen");
define("_PAGESVIEWS","tallatot kaptunk az oldal indtsa ta:");
define("_TOPIC","Tma");
define("_UDOWNLOADS","Szmll");
define("_VOTE","szavazat");
define("_VOTES","szavazat");
define("_MVIEWADMIN","Csak adminisztrtoroknak");
define("_MVIEWUSERS","Csak regisztrlt tagoknak");
define("_MVIEWANON","Csak nvtelen ltogatknak");
define("_MVIEWALL","Minden ltogatnak");
define("_EXPIRELESSHOUR","Lejrat: kevesebb, mint egy ra");
define("_EXPIREIN","Lejrat ideje:");
define("_HTTPREFERERS","HTTP utalsok");
define("_UNLIMITED","Korltlan");
define("_HOURS","ra");
define("_RSSPROBLEM","Jelenleg nem mkdik a site tartalomszolgltatsa");
define("_SELECTLANGUAGE","Vlassz nyelvet");
define("_SELECTGUILANG","Vlassz nyelvet:");
define("_NONE","Semmi");
define("_BLOCKPROBLEM","<center>There is a problem right now with this block.</center>");
define("_BLOCKPROBLEM2","<center>There isn't content right now for this block.</center>");
define("_MODULENOTACTIVE","Sorry, this Module isn't active!");
define("_NOACTIVEMODULES","Inactive Modules");
define("_FORADMINTESTS","(for Admin tests)");
define("_BBFORUMS","Forums");
define("_ACCESSDENIED", "Access Denied");
define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
define("_DATESTRING","%B %d, %A, %T");
define("_DATESTRING2","%B %d, %A");
define("_DATE","Date");
define("_HOUR","Hour");
define("_UMONTH","Month");
define("_YEAR","Year");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>
